Skip to contents

Validate and visualise juggling patterns expressed in siteswap notation. Supports vanilla, synchronous, multiplex, synchronous multiplex, and passing siteswap, with tools to check pattern validity and to retrieve raw throw data for custom visualisations. Patterns can be plotted as timeline arc diagrams or ladder diagrams, and animated via the 'JugglingLab' animation server (https://jugglinglab.org/html/animinfo.html).

Author

Maintainer: Ella Kaye hello@ellakaye.co.uk [copyright holder]

Authors: